# RCK Python SDK

[![Python Version](https://img.shields.io/badge/python-3.7+-blue.svg)](https://python.org)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)

一个优雅的Python SDK，用于访问RCK (Relational Calculate Kernel) API服务。

## 🌟 主要功能

- **文本计算和分析**: 强大的自然语言处理能力
- **图像生成和渲染**: 多样化的艺术风格图像生成
- **多模态资源处理**: 支持文本、图像等多种输入
- **自定义输出格式**: 灵活的JSON Schema输出定义
- **简洁易用**: 直观的API设计，快速上手

## 📦 安装

### 从PyPI安装（推荐）
```bash
pip install rck-python-sdk
```

### 从源码安装
```bash
git clone https://github.com/rck/rck-python-sdk.git
cd rck-python-sdk
pip install -e .
```

## 🚀 快速开始

### 基础使用

```python
from rck_sdk import RCKClient

# 初始化客户端
client = RCKClient(api_key="your-api-key")

# 文本分析
result = client.compute.analyze(
    text="床前明月光，疑是地上霜",
    task="分析诗歌的情感和主题"
)
print(result.data)

# 图像生成
image = client.image.generate(
    prompt="山水画风格的风景",
    composition="远山近水的构图",
    lighting="柔和的晨光",
    style="中国传统水墨画风格"
)

# 保存图像
if image.success:
    saved_files = client.image.save_images(image, "landscape")
    print(f"图像已保存: {saved_files}")
```

### 高级功能

```python
# 自定义输出格式
custom_schema = {
    "type": "object",
    "properties": {
        "emotion": {"type": "string"},
        "theme": {"type": "string"},
        "analysis": {"type": "string"}
    }
}

result = client.compute.custom_compute(
    text="春眠不觉晓，处处闻啼鸟",
    task="深度分析诗歌",
    output_schema=custom_schema
)

# 多模态创作
resources = [
    {"image_1": "https://example.com/image1.jpg"}
]

poem = client.compute.create_poem(
    inspiration="基于图片的意境创作",
    style="五言绝句",
    resources=resources
)
```

## 📖 文档

- [完整API文档](https://rck-python-sdk.readthedocs.io/)
- [示例代码](./examples/)
- [更新日志](./CHANGELOG.md)

## 🤝 贡献

欢迎提交Issue和Pull Request！

## 📄 许可证

本项目采用MIT许可证 - 查看 [LICENSE](LICENSE) 文件了解详情。

## 🆘 支持

如有问题，请通过以下方式联系我们：
- 邮箱: support@rck.ai  
- GitHub Issues: [提交问题](https://github.com/rck/rck-python-sdk/issues) 