"""
RCK SDK 高级功能示例
"""

from rck_sdk import RCKClient

def multimodal_example():
    """多模态资源示例"""
    print("=== 多模态资源示例 ===")
    
    client = RCKClient(api_key="askr-omorsablin-616-624-topos-owner")
    
    # 多模态创作
    resources = [
        {"image_1": "https://i.ibb.co/3kC775P/image.png"},
        {"image_2": "https://i.ibb.co/Hdr3D9c/image.png"}
    ]
    
    result = client.compute.create_poem(
        inspiration="请感受这些图片中描绘的意境",
        style="五言绝句",
        resources=resources
    )
    
    print(f"多模态创作结果: {result.data}")
    print()

def translation_example():
    """翻译功能示例"""
    print("=== 翻译功能示例 ===")
    
    client = RCKClient(api_key="askr-omorsablin-616-624-topos-owner")
    
    result = client.compute.translate(
        text="山重水复疑无路，柳暗花明又一村。",
        target_language="English",
        include_cultural_notes=True
    )
    
    print(f"翻译结果: {result.data}")
    print()

def art_styles_example():
    """多种艺术风格示例"""
    print("=== 多种艺术风格示例 ===")
    
    client = RCKClient(api_key="askr-omorsablin-616-624-topos-owner")
    
    styles = [
        "中国传统水墨画风格",
        "西方古典油画风格", 
        "现代抽象艺术风格"
    ]
    
    results = client.image.generate_art_styles(
        prompt="古老的城堡坐落在山顶",
        styles=styles,
        composition="居中构图，突出城堡的宏伟",
        lighting="戏剧性的夕阳光影"
    )
    
    for i, result in enumerate(results):
        if result.success:
            saved_files = client.image.save_images(result, f"castle_style_{i+1}")
            print(f"风格 {i+1} 图像已保存: {saved_files}")

def workflow_example():
    """完整工作流示例"""
    print("=== 完整工作流示例 ===")
    
    client = RCKClient(api_key="askr-omorsablin-616-624-topos-owner")
    
    # 步骤1: 诗歌转场景描述
    poem = "空山不见人，但闻人语响。返景入深林，复照青苔上。"
    
    scene_result = client.compute.custom_compute(
        text=poem,
        task="分析诗歌内容，创建详细的视觉化场景描述",
        output_schema={
            "type": "object",
            "properties": {
                "scene_description": {
                    "type": "object", 
                    "properties": {
                        "main_subjects": {"type": "string"},
                        "lighting": {"type": "string"},
                        "composition": {"type": "string"},
                        "style": {"type": "string"}
                    }
                }
            }
        },
        target_art_style="中国传统水墨画"
    )
    
    print(f"场景描述: {scene_result.data}")
    
    # 步骤2: 场景转图像
    scene_desc = scene_result['scene_description']
    
    image_result = client.image.generate(
        prompt=scene_desc['main_subjects'],
        composition=scene_desc['composition'],
        lighting=scene_desc['lighting'],
        style=scene_desc['style']
    )
    
    if image_result.success:
        saved_files = client.image.save_images(image_result, "poem_to_image")
        print(f"诗歌转图像完成: {saved_files}")

if __name__ == "__main__":
    multimodal_example()
    translation_example()
    art_styles_example()
    workflow_example()
