"""
RCK SDK 基础使用示例
"""

from rck_sdk import RCKClient

def main():
    # 初始化客户端
    client = RCKClient(api_key="askr-omorsablin-616-624-topos-owner")
    
    # 测试连接
    print("=== 连接测试 ===")
    connection_test = client.test_connection()
    print(f"连接状态: {connection_test['status']}")
    print(f"消息: {connection_test['message']}")
    print()
    
    # 文本分析示例
    print("=== 文本分析示例 ===")
    poem = "床前明月光，疑是地上霜。举头望明月，低头思故乡。"
    
    result = client.compute.analyze(
        text=poem,
        task="分析这首诗的情感和主题",
        output_format="basic_analysis"
    )
    
    print(f"诗歌: {poem}")
    print(f"分析结果: {result.data}")
    print()
    
    # 图像生成示例
    print("=== 图像生成示例 ===")
    image_response = client.image.generate(
        prompt="连绵起伏的青山环绕着一汪清澈的湖水",
        composition="宽阔的全景镜头，展现山水之美",
        lighting="清晨的柔和阳光，营造宁静氛围",
        style="中国传统山水画风格，水墨淡彩"
    )
    
    print(f"图像生成结果: 成功={image_response.success}, 数量={image_response.count}")
    
    if image_response.success:
        # 保存图像
        saved_files = client.image.save_images(image_response, "mountain_lake")
        print(f"图像已保存: {saved_files}")
    
    print()
    
    # 自定义输出格式示例
    print("=== 自定义输出格式示例 ===")
    custom_schema = {
        "type": "object",
        "properties": {
            "mood": {"type": "string"},
            "imagery": {"type": "array", "items": {"type": "string"}},
            "literary_devices": {"type": "array", "items": {"type": "string"}},
            "interpretation": {"type": "string"}
        }
    }
    
    result = client.compute.custom_compute(
        text="春眠不觉晓，处处闻啼鸟。夜来风雨声，花落知多少。",
        task="深度分析这首诗的文学价值",
        output_schema=custom_schema,
        analysis_style="学术研究"
    )
    
    print(f"自定义分析结果: {result.data}")

if __name__ == "__main__":
    main() 