"""
RCK Python SDK

一个优雅的Python SDK，用于访问RCK (Relational Calculate Kernel) API服务。

主要功能:
- 文本计算和分析
- 图像生成和渲染
- 多模态资源处理
- 自定义输出格式

使用示例:
    from rck_sdk import RCKClient
    
    client = RCKClient(api_key="your-api-key")
    
    # 文本计算
    result = client.compute.analyze(
        text="床前明月光，疑是地上霜",
        task="分析诗歌的情感和主题"
    )
    
    # 图像生成
    image = client.image.generate(
        prompt="山水画风格的风景",
        style="中国传统水墨画"
    )
"""

from .client import RCKClient
from .core.exceptions import (
    RCKError,
    AuthenticationError,
    ValidationError,
    APIError
)

# 版本信息
__version__ = "1.0.0"
__author__ = "RCK Team"
__email__ = "support@rck.ai"

# 导出主要API
__all__ = [
    "RCKClient",
    "RCKError", 
    "AuthenticationError",
    "ValidationError",
    "APIError",
    "__version__"
] 