"""
常用的输出格式Schema定义
"""

from typing import Dict, Any

# 预定义的常用输出格式
PREDEFINED_SCHEMAS = {
    "basic_analysis": {
        "type": "object",
        "properties": {
            "emotion": {"type": "string", "description": "情感分析结果"},
            "theme": {"type": "string", "description": "主题分析"},
            "analysis": {"type": "string", "description": "详细分析"}
        },
        "required": ["emotion", "theme", "analysis"]
    },
    
    "poem_creation": {
        "type": "object", 
        "properties": {
            "poem": {"type": "string", "description": "创作的诗歌"},
            "creative_process": {"type": "string", "description": "创作思路"},
            "style_notes": {"type": "string", "description": "风格说明"}
        },
        "required": ["poem"]
    },
    
    "scene_description": {
        "type": "object",
        "properties": {
            "scene_description": {
                "type": "object",
                "properties": {
                    "main_subjects": {"type": "string", "description": "主要主体和空间关系"},
                    "lighting": {"type": "string", "description": "光照条件和氛围"},
                    "composition": {"type": "string", "description": "画面构图"},
                    "style": {"type": "string", "description": "艺术风格"}
                },
                "required": ["main_subjects", "lighting", "composition", "style"]
            }
        },
        "required": ["scene_description"]
    },
    
    "translation": {
        "type": "object",
        "properties": {
            "translation": {"type": "string", "description": "翻译结果"},
            "original_language": {"type": "string", "description": "源语言"},
            "target_language": {"type": "string", "description": "目标语言"},
            "cultural_notes": {"type": "string", "description": "文化背景说明"}
        },
        "required": ["translation"]
    }
}

def get_schema(schema_name: str) -> Dict[str, Any]:
    """获取预定义的Schema"""
    if schema_name not in PREDEFINED_SCHEMAS:
        raise ValueError(f"未知的Schema名称: {schema_name}")
    return PREDEFINED_SCHEMAS[schema_name].copy()