"""
认证管理模块
"""

from typing import Optional
from .exceptions import AuthenticationError

class AuthManager:
    """认证管理器"""
    
    def __init__(self, api_key: str):
        """
        初始化认证管理器
        
        :param api_key: Topos API密钥
        """
        if not api_key:
            raise AuthenticationError("API密钥不能为空")
        
        if not isinstance(api_key, str):
            raise AuthenticationError("API密钥必须是字符串类型")
        
        # 简单的API密钥格式验证
        if len(api_key) < 10:
            raise AuthenticationError("API密钥格式无效")
        
        self.api_key = api_key
    
    def get_auth_headers(self) -> dict:
        """获取认证请求头"""
        return {
            "topos-api-key": self.api_key
        }
    
    def validate_key(self) -> bool:
        """验证API密钥格式（基础验证）"""
        return bool(self.api_key and len(self.api_key) >= 10) 