"""
RCK SDK 自定义异常类
"""

class RCKError(Exception):
    """RCK SDK 基础异常类"""
    def __init__(self, message: str, error_code: str = None):
        super().__init__(message)
        self.message = message
        self.error_code = error_code

class AuthenticationError(RCKError):
    """认证失败异常"""
    def __init__(self, message: str = "认证失败，请检查API密钥"):
        super().__init__(message, "AUTH_FAILED")

class ValidationError(RCKError):
    """参数验证失败异常"""
    def __init__(self, message: str, field: str = None):
        super().__init__(message, "VALIDATION_ERROR")
        self.field = field

class APIError(RCKError):
    """API请求失败异常"""
    def __init__(self, message: str, status_code: int = None, response_data: dict = None):
        super().__init__(message, "API_ERROR")
        self.status_code = status_code
        self.response_data = response_data

class NetworkError(RCKError):
    """网络连接异常"""
    def __init__(self, message: str = "网络连接失败"):
        super().__init__(message, "NETWORK_ERROR")

class TimeoutError(RCKError):
    """请求超时异常"""
    def __init__(self, message: str = "请求超时"):
        super().__init__(message, "TIMEOUT_ERROR") 