"""
请求数据模型
"""

from typing import Dict, Any, List, Optional
from dataclasses import dataclass

@dataclass
class ComputeRequest:
    """文本计算请求模型"""
    start_point: str
    expect_path: str
    output_schema: Optional[Dict[str, Any]] = None
    custom_fields: Optional[Dict[str, str]] = None
    resources: Optional[List[Dict[str, str]]] = None
    
    def to_dict(self) -> Dict[str, Any]:
        """转换为API请求格式"""
        # 构建 start_point
        start_point_obj = {"startPoint": self.start_point}
        if self.resources:
            start_point_obj["resource"] = self.resources
        
        # 构建 path
        path_obj = {"expectPath": self.expect_path}
        
        # 添加输出格式
        if self.output_schema:
            import json
            path_obj["endpointClass"] = json.dumps(self.output_schema)
        else:
            # 默认输出格式
            path_obj["endpointClass"] = '{"type": "object", "properties": {"emotion": {"type": "string"}, "theme": {"type": "string"}, "analysis": {"type": "string"}}}'
        
        # 添加自定义字段
        if self.custom_fields:
            path_obj.update(self.custom_fields)
        
        return {
            "start_point": start_point_obj,
            "path": path_obj
        }

@dataclass
class ImageRequest:
    """图像生成请求模型"""
    start_point: str
    composition: str
    lighting: str
    style: str
    
    def to_dict(self) -> Dict[str, Any]:
        """转换为API请求格式"""
        return {
            "start_point": {
                "startPoint": self.start_point
            },
            "path": {
                "frame_Composition": self.composition,
                "lighting": self.lighting,
                "style": self.style
            }
        } 