"""
SDK日志配置
"""

import logging
import sys
from typing import Optional

def setup_logger(
    name: str = "rck_sdk",
    level: int = logging.INFO,
    format_string: Optional[str] = None
) -> logging.Logger:
    """
    设置SDK日志器
    
    :param name: 日志器名称
    :param level: 日志级别
    :param format_string: 自定义日志格式
    :return: 配置好的日志器
    """
    logger = logging.getLogger(name)
    
    # 避免重复添加处理器
    if logger.handlers:
        return logger
    
    logger.setLevel(level)
    
    # 创建控制台处理器
    console_handler = logging.StreamHandler(sys.stdout)
    console_handler.setLevel(level)
    
    # 设置日志格式
    if not format_string:
        format_string = '[%(asctime)s] [%(name)s] [%(levelname)s] - %(message)s'
    
    formatter = logging.Formatter(format_string, datefmt='%Y-%m-%d %H:%M:%S')
    console_handler.setFormatter(formatter)
    
    logger.addHandler(console_handler)
    
    return logger

# 默认日志器
default_logger = setup_logger() 